@@ -13,6 +13,7 @@ use serde::Deserialize;
 use crate::config;
 use crate::gitlab::Labels as GLLabels;
 use crate::gitlab::ProjectMembers as GLMembers;
+use crate::gitlab::Project as GLProject;
 use crate::gitlab::Query;
 use crate::gitlab;
 use crate::utils;
@@ -35,7 +36,7 @@ enum RemoteType {
 #[derive(GraphQLQuery)]
 #[graphql(
     schema_path = "src/graphql/schema.json",
-    query_path = "src/graphql/ProjectsWithRemotes.graphql",
+    query_path = "src/graphql/projects_with_remotes.graphql",
     response_derives = "Debug"
 )]
 struct ProjectsWithRemotes;
@@ -74,6 +75,8 @@ fn get_remotes_from_server(search_str: &str, gitlabclient: &gitlab::Client) -> R
         }
     );
 
+    debug!("graphql search string: {}", search_str);
+
     let response = gitlabclient.graphql::<ProjectsWithRemotes>(&query_body)
         .context("GraphQL error when looking for Projects with matching remotes")?;
 
@@ -143,6 +146,46 @@ fn get_project_members(project_id: u64, gitlabclient: &gitlab::Client) -> Result
     Ok(members.iter().map(|m| format!("{}:{}", m.id.to_string(), m.username.clone())).collect())
 }
 
+fn get_project_path_with_namespace(project_id: u64, gitlabclient: &gitlab::Client) -> Result<String> {
+    let mut project_builder  = GLProject::builder();
+    let endpoint = project_builder.project(project_id).build()
+        .map_err(|e| anyhow!("Could not fetch project from server.\n {}",e))?;
+
+    debug!("endpoint: {:#?}", endpoint);
+
+    #[derive(Deserialize, Debug)]
+    struct Project {
+        path_with_namespace: String
+    }
+
+    let project: Project = endpoint
+        .query(gitlabclient)
+        .context("Failed to query project")?;
+
+    debug!("project: {:#?}", project);
+    Ok(project.path_with_namespace)
+}
+
+fn get_project_defaultbranch(project_id: u64, gitlabclient: &gitlab::Client) -> Result<String> {
+    let mut project_builder  = GLProject::builder();
+    let endpoint = project_builder.project(project_id).build()
+        .map_err(|e| anyhow!("Could not fetch project from server.\n {}",e))?;
+
+    debug!("endpoint: {:#?}", endpoint);
+
+    #[derive(Deserialize, Debug)]
+    struct Project {
+        default_branch: String
+    }
+
+    let project: Project = endpoint
+        .query(gitlabclient)
+        .context("Failed to query project")?;
+
+    debug!("project: {:#?}", project);
+    Ok(project.default_branch)
+}
+
 fn get_project_labels(project_id: u64, gitlabclient: &gitlab::Client) -> Result<Vec<String>> {
     let mut labels_builder = GLLabels::builder();
     let endpoint = labels_builder.project(project_id).build()
@@ -187,7 +230,10 @@ this by manually obtaining the project's ID from the GUI and adding it to your r
             Err(anyhow!("Git remote 'origin' not found. Set the remote or pass the project details explicitly"))
         }
     }?;
+
     config.projectid = Some(project_id);
+    config.defaultbranch = get_project_defaultbranch(project_id, &gitlabclient).ok();
+    config.path_with_namespace = get_project_path_with_namespace(project_id, &gitlabclient).ok();
     config.labels = get_project_labels(project_id, &gitlabclient)?;
     config.members = get_project_members(project_id, &gitlabclient)?;
     config.save(config::GitConfigSaveableLevel::Repo)?;
