@@ -1,31 +1,14 @@
 use anyhow::{anyhow, Context, Result};
-use serde::Deserialize;
 
+use crate::cmds::project::{generate_basic_project_builder, Project};
 use crate::config;
-use crate::gitlab::{Client, ProjectBuilder, Query};
 use crate::gitlab::Project as GLProject;
+use crate::gitlab::{Client, Query};
 use crate::utils;
 
-#[derive(Debug, Deserialize)]
-struct Project {
-    web_url: String,
-}
-
-pub fn generate_project_builder<'a>(
-    args: &'a clap::ArgMatches,
-    config: &'a config::Config,
-    p: &'a mut ProjectBuilder<'a>,
-) -> Result<GLProject<'a>> {
-
-    let project_id = utils::get_proj_from_arg_or_conf(&args, &config)?;
-    p.project(project_id);
-    p.build()
-        .map_err(|e| anyhow!("Could not construct query to fetch project URL from server.\n {}",e))
-}
-
 pub fn open_project_cmd(args: clap::ArgMatches, config: config::Config, gitlabclient: Client) -> Result<()> {
     let mut p = GLProject::builder();
-    let endpoint = generate_project_builder(&args, &config, &mut p)?;
+    let endpoint = generate_basic_project_builder(&args, &config, &mut p)?;
 
     debug!("args: {:#?}", args);
     debug!("endpoint: {:#?}", endpoint);
